from setuptools import setup

setup(
    name='Aditzak',
    version='0.3.20',    
    description='A Python package to analyse and build Euskera/Basque verbs.',
    url='https://github.com/HCook86/Aditzak/',
    author='',
    author_email='aditzaksoftware@gmail.com',
    license='BSD 2-clause',
    packages=['Aditzak'],
    classifiers=[
        'Development Status :: 1 - Planning',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: BSD License',  
        'Operating System :: OS Independent',
        "Programming Language :: Python :: 3"
    ],
    include_package_data=True
)


def check_case(args):
    if (args["Nor"] != None) and (args["Nori"] == None) and (args["Nork"] == None):
        return "NOR"
    elif (args["Nor"] != None) and (args["Nori"] != None) and (args["Nork"] == None):
        return "NOR-NORI"  
    elif (args["Nor"] != None) and (args["Nori"] == None) and (args["Nork"] != None):
        return "NOR-NORK"
    elif (args["Nor"] != None) and (args["Nori"] != None) and (args["Nork"] != None):
        return "NOR-NORI-NORK"
    else:
        raise ValueError(('Incorrect value for Kasua. Read README.md or the documentation at https://github.com/HCook86/Aditzak/blob/heroku/README.md for more information'))


#analyze({"Aditza":None, "Kasua":"NOR-NORK", "Modua":"Ahalera","Denbora":"Oraina", "Nor":"zuek", "Nori":None, "Nork":"hark"})